import logging

import butterflow as root


def main() -> None:
    logging.basicConfig(format=root.LOG_FMT, level=root.LOG_LVL)
    log = logging.getLogger(__name__)

    if root.DEBUG:
        log.info("Debug mode is ON")

    print("Hello world!")


if __name__ == "__main__":
    main()



# butterflow documentation build configuration file.
import butterflow as root


# -- General configuration ------------------------------------------------

extensions = [
    "sphinx.ext.autodoc",
    "sphinx.ext.intersphinx",
    "sphinx.ext.todo",
    "sphinx.ext.viewcode",
]

templates_path = ["_templates"]
source_suffix = [".rst"]
master_doc = "index"

# General information about the project.
project = "butterflow"
author = "Kristian Boda"
copyright = f"2020, {author}"

# The short X.Y version.
version = root.__version__
# The full version, including alpha/beta/rc tags.
release = root.__release__

language = None
exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]
pygments_style = "sphinx"
todo_include_todos = True


# -- Options for HTML output ----------------------------------------------

html_theme = "alabaster"

html_theme_options = {
    # Alabaster theme configuration.
    "page_width": "75%",
}

html_static_path = ["_static"]
html_show_copyright = True


# -- Options for LaTeX output ---------------------------------------------

latex_elements = {
    "papersize": "a4paper",
    "pointsize": "10pt",
    "figure_align": "htbp",
}

latex_documents = [
    (master_doc, "butterflow.tex", "butterflow documentation", author, "manual")
]



import re

from pathlib import Path
from textwrap import dedent
from typing import List

from setuptools import (
    find_packages,
    setup,
)

import butterflow as root


def read_requirements(file: str) -> List[str]:
    if not Path(file).is_file():
        raise FileNotFoundError(file)
    with open(file) as fd:
        unparsed_requirements = fd.read()
        return re.findall(r"[\w-]+==[\d.]+", unparsed_requirements)

setup_params = dict(
    name='butterflow',

    version=root.__version__,

    description='Python project',

    long_description=dedent("""
        The boilerplate Python project that aims to create facility for maintaining of the package
        easily. It considering tools for building, testing and distribution.
        """).strip(),
    long_description_content_type='text/markdown',
    author='Kristian Boda',
    author_email='kristian.boda@babylonhealth.com',
    url='https://john.doe.org',

    classifiers=["Programming Language :: Python :: 3"],
    license='MIT',
    keywords=[],

    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,

    entry_points={
        'console_scripts': [
            'butterflow = butterflow.__main__:main',
        ]
    },

    install_requires=read_requirements('requirements.txt'),
    extras_require={},
    setup_requires=[
        'wheel',
    ],
    tests_require=read_requirements('requirements-test.txt')
)


def main() -> None:
    setup(**setup_params)


if __name__ == '__main__':
    main()



import logging

__version__ = "0.0.1"
__release__ = __version__

DEBUG = False

LOG_FMT = (
    "%(levelname)s: %(name)s [%(process)d] {%(filename)s@L%(lineno)d}: %(message)s"
)
LOG_LVL = logging.INFO



import pytest


class TestButterflow:
    def _setup(self) -> None:
        pass

    def _teardown(self) -> None:
        pass

    def test_butterflow(self) -> None:
        self._setup()
        assert True
        self._teardown()


if __name__ == "__main__":
    pytest.main(args=[__file__])
